chain_ids_match

Function chain_ids_match 

pub fn chain_ids_match(a: &str, b: &str) -> bool
Compare two chain identifier strings, each of which may independently be in the canonical Base58 form or the legacy hex short form. A short form matches a full form if it encodes the first 4 bytes of the digest. Strings in neither format (e.g. ad-hoc identifiers used by tests or other flavors) only match by exact string equality.